using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Velleman.Velbus;

namespace DemoAsync
{
    public partial class MainForm : Form
    {
        /* Create a new SerialBus instance */
        private SerialBus m_Bus = new SerialBus();

        public MainForm()
        {
            InitializeComponent();

            m_Bus.PacketReceived += new BusPacketIoEventHandler(PacketReceived);
            m_Bus.PacketSent += new BusPacketIoEventHandler(PacketSent);
        }

        private void btnConnect_Click(object sender, EventArgs e)
        {
            /* Connect to the specified port */
            m_Bus.PortName = cbPort.Text;
            m_Bus.Open();
        }

        private void btnDisconnect_Click(object sender, EventArgs e)
        {
            /* Close the port */
            m_Bus.Close();
        }

        private void btnScan_Click(object sender, EventArgs e)
        {
            /* Send out module type request to each possible address. These
             * packets are useful for scanning purposes, since modules will react
             * to them. */

            Packet packet = new Packet();         // no databytes, default address
            packet.Priority = PacketPriority.Low; // low priority
            packet.Rtr = true;                    // rtr must be enabled

            for (int i = 0x02; i <= 0xFF; i++)
            {
                // loop over all possible addresses
                // and send out our scan packet
                packet.Address = (byte)i;
                m_Bus.Send(packet);
            }
        }

        private void WriteLog(string msg)
        {
            /* Since the input/output operations for asynchronous IO occur on
             * a secundary thread, we need to synchronize it with our GUI thread.
             * This is the same method as if you would use the SerialPort component */

            if (lstLog.InvokeRequired)
                lstLog.BeginInvoke(new MethodInvoker(delegate() { WriteLog(msg); }));
            else
                lstLog.Items.Add(msg);
        }

        private void PacketReceived(object source, BusPacketIoEventArgs args)
        {
            // Log read operation
            WriteLog(String.Format("Packet received from address {0}", args.Packet.Address));
        }

        public void PacketSent(object source, BusPacketIoEventArgs args)
        {
            // Log write operation
            WriteLog(String.Format("Packet sent to address {0}", args.Packet.Address));
        }

        private void MainForm_FormClosed(object sender, FormClosedEventArgs e)
        {
            m_Bus.Close(); // Be sure to clean up
        }
    }
}