/*
 * Velbus Serial Communications Library for .NET
 * Copyright (C) 2007 Velleman
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 */
#region "Imports"

using System;
using System.Collections.Generic;
using System.Text;

#endregion

namespace Velleman.Velbus
{
    /// <summary>
    /// Provides data for the PacketReceived and PacketSent events.
    /// </summary>
    public class BusPacketIoEventArgs : EventArgs
    {
        /// <summary>
        /// Packet that was sent/received.
        /// </summary>
        private Packet m_Packet;

        /// <summary>
        /// Initializes a new instance of the BusPacketIoEventArgs class.
        /// </summary>
        /// <param name="packet">Packet attached to the event.</param>
        public BusPacketIoEventArgs(Packet packet)
        {
            if (packet == null)
                throw new NullReferenceException();
            m_Packet = packet;
        }

        /// <summary>
        /// Gets the packet attached to the event.
        /// </summary>
        public Packet Packet
        {
            get
            {
                return m_Packet;
            }
        }
    }
}
