/*
 * Velbus Serial Communications Library for .NET
 * Copyright (C) 2007 Velleman
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 */
#region "Imports"

using System;
using System.Collections.Generic;
using System.Text;

#endregion

namespace Velleman.Velbus
{
    /// <summary>
    /// Velbus input-output event handler.
    /// </summary>
    /// <param name="source">Object which initiated the event.</param>
    /// <param name="args">Event arguments accompanying the event.</param>
    public delegate void BusPacketIoEventHandler(
        object source, BusPacketIoEventArgs args);

    /// <summary>
    /// Interface class for Velbus communications modules.
    /// </summary>
    public interface IBusInterface
    {
        /// <summary>
        /// Delay between ansynchronous operations.
        /// </summary>
        int Delay
        {
            get;
            set;
        }

        ///<summary>
        /// Represents the method that will handle the packet received event
        /// of the IBusInterface descendant.
        /// </summary>
        event BusPacketIoEventHandler PacketReceived;

        ///<summary>
        /// Represents the method that will handle the packet sent event
        /// of the IBusInterface descendant.
        /// </summary>
        event BusPacketIoEventHandler PacketSent;

        /// <summary>
        /// Generic method to open the communication stream.
        /// </summary>
        void Open();

        /// <summary>
        /// Generic method to close the communication stream.
        /// </summary>
        void Close();

        /// <summary>
        /// Returns the current communications state.
        /// </summary>
        bool IsOpen
        {
            get;
        }

        /// <summary>
        /// Sends a packet in blocking mode.
        /// </summary>
        /// <param name="packet">The packet to send.</param>
        void SendBlocking(Packet packet);

        /// <summary>
        /// Sends a packet in non-blocking mode (default).
        /// </summary>
        /// <param name="packet">The packet to send.</param>
        void Send(Packet packet);
    }
}
